==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/TenguCameraItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.item.ModItems;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1796;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3419;

public class TenguCameraItem extends class_1792 {

    public TenguCameraItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        if (!world.field_9236 && world instanceof class_3218 serverWorld && user instanceof class_3222 player) {
            var center = user.method_24515();
            var entities = serverWorld.method_8390(
                    class_1297.class,
                    new class_238(
                            center.method_10263() - 16, center.method_10264() - 16, center.method_10260() - 16,
                            center.method_10263() + 16, center.method_10264() + 16, center.method_10260() + 16
                    ),
                    entity -> entity != user
            );
            player.method_6092(new class_1293(class_1294.field_5919, 15, 0, false, false));
            player.method_6092(new class_1293(class_1294.field_5925, 3 * 20, 0, false, false));
            for (class_1297 entity : entities) {
                if (entity instanceof class_1309 livingEntity) {
                    livingEntity.method_6092(new class_1293(class_1294.field_5912, 5 * 20, 1, false, false));
                    livingEntity.method_6092(new class_1293(class_1294.field_5919, (int) (1.5 * 2 * 20), 0, false, false));
                    livingEntity.method_6092(new class_1293(class_1294.field_5919, (int) (1.5 * 2 * 20), 0, false, false));
                }
                if (entity instanceof DanmakuEntity danmakuEntity) {
                    serverWorld.method_8649(
                            new class_1542(serverWorld,
                                    danmakuEntity.method_23317(),
                                    danmakuEntity.method_23318(),
                                    danmakuEntity.method_23321(),
                                    new class_1799(ModItems.POINT)
                            )
                    );
                    danmakuEntity.method_31472();
                }
            }
            world.method_45447(null, player.method_24515(), SoundEventInit.PHOTO, class_3419.field_15248);

            class_1796 itemCooldownManager = user.method_7357();
            itemCooldownManager.method_62835(itemStack, 30);

            if (!user.method_56992()) {
                itemStack.method_61653(1, user);
            }
            if (itemStack.method_7963() && itemStack.method_7919() >= itemStack.method_7936()) {
                itemStack.method_7934(1);
            }
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/TenguCameraItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1796;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_238;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3419;

public class TenguCameraItem extends class_1792 {

    public TenguCameraItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        if (!world.field_9236 && world instanceof class_3218 serverWorld && user instanceof class_3222 player) {
            var center = user.method_24515();
            var entities = serverWorld.method_8390(
                    class_1297.class,
                    new class_238(
                            center.method_10263() - 16, center.method_10264() - 16, center.method_10260() - 16,
                            center.method_10263() + 16, center.method_10264() + 16, center.method_10260() + 16
                    ),
                    entity -> entity != user
            );
            player.method_6092(new class_1293(class_1294.field_5919, 15, 0, false, false));
            player.method_6092(new class_1293(class_1294.field_5925, 3 * 20, 0, false, false));
            for (class_1297 entity : entities) {
                if (entity instanceof class_1309 livingEntity) {
                    livingEntity.method_6092(new class_1293(class_1294.field_5912, 5 * 20, 1, false, false));
                    livingEntity.method_6092(new class_1293(class_1294.field_5919, (int) (1.5 * 2 * 20), 0, false, false));
                    livingEntity.method_6092(new class_1293(class_1294.field_5919, (int) (1.5 * 2 * 20), 0, false, false));
                }
                if (entity instanceof DanmakuEntity danmakuEntity) {
                    serverWorld.method_8649(
                            new class_1542(serverWorld,
                                    danmakuEntity.method_23317(),
                                    danmakuEntity.method_23318(),
                                    danmakuEntity.method_23321(),
                                    new class_1799(RDItems.POINT)
                            )
                    );
                    danmakuEntity.method_31472();
                }
            }
            world.method_45447(null, player.method_24515(), SoundEventInit.PHOTO, class_3419.field_15248);

            class_1796 itemCooldownManager = user.method_7357();
            itemCooldownManager.method_62835(itemStack, 30);

            if (!user.method_56992()) {
                itemStack.method_61653(1, user);
            }
            if (itemStack.method_7963() && itemStack.method_7919() >= itemStack.method_7936()) {
                itemStack.method_7934(1);
            }
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}
